===========
Main module
===========

.. contents:: Overview
   :local:

For more details regarding the main classes, see:

.. toctree::
   :maxdepth: 1

   nngt/graph-classes
   nngt/main-functions
   nngt/side-classes

.. automodule:: nngt
   :noindex:
   :no-members:

.. currentmodule:: nngt

.. autosummary::

    nngt.Graph
    nngt.GroupProperty
    nngt.Network
    nngt.NeuralGroup
    nngt.NeuralPop
    nngt.SpatialGraph
    nngt.SpatialNetwork
    nngt.generate
    nngt.get_config
    nngt.load_from_file
    nngt.num_mpi_processes
    nngt.on_master_process
    nngt.save_to_file
    nngt.seed
    nngt.set_config
    nngt.use_backend

.. toctree::
   :hidden:

   analysis
   core
   generation
   geometry
   lib
   plot
   simulation
